Skip to contents

Create a lazy JSON tbl

Usage

tbl_lazy_json(session, json_name, compute_steps = list())

Arguments

session

A shiny session object.

json_name

A character.

compute_steps

A list of compute steps to be triggered when compute() is called.

Value

An object of class tbl_lazy_json: a list holding the shiny session, a state_id keying the data in the browser, and the list of compute_steps to run when the pipeline is computed.