Add filter to JSON data.
Arguments
- .data
A
tbl_lazy_jsonobject.- ...
Filtering expressions. Comparisons (
==,>,<, etc.) combined with&/|are supported, as well as thedplyrhelpersis.na(),between(), andacross()/if_all()/if_any().across()/if_all()andif_any()expand the predicate over the selected columns, combining them with&and|respectively. Column selections acceptc(...), a bare column, a character vector, andall_of()/any_of(). Values referenced frominputor the calling environment are resolved on the R side; column references are evaluated in the browser.