Rename columns of JSON data.
Value
A tbl_lazy_json object with the rename appended as a lazy compute
step, applied in the browser when the pipeline is evaluated.
Examples
if (interactive()) {
tbl(session, "mtcars") |>
rename(miles_per_gallon = mpg, cylinders = cyl)
}