Summarise JSON data.
Arguments
- .data
A
tbl_lazy_jsonobject.- ...
Name-value pairs of summary functions. The name gives the name of the column in the output. The value should be a call to a summary function like
mean(),sum(),min(),max(),n().across()is expanded on the R side into one summary per selected column. It accepts a single function (across(c(a, b), mean)) or a named list of functions (across(c(a, b), list(mean = mean, sd = sd))). Column selections acceptc(...), a bare column, a character vector, andall_of()/any_of(). Use.nameswith the{.col}/{.fn}glue placeholders to control the output column names; by default a single function reuses the input name and multiple functions produce{.col}_{.fn}.